@@ -66,7 +66,7 @@ extern ext2_loff_t ext2_llseek(unsigned int fd,
 			})
 
 
-#define VERSION	"2.0 (>2GB)"
+#define VERSION	"2.0a (>2GB)"
 
 #define DEFAULT_DEVICE	"/dev/hda"
 #define ALTERNATE_DEVICE "/dev/sda"
@@ -729,7 +729,7 @@ static void check_consistency(struct partition *p, int partition)
 	long2chs(p->start_sect + p->nr_sects - 1, &lec, &leh, &les);
 
 /* Same physical / logical beginning? */
-	if (pbc != lbc || pbh != lbh || pbs != lbs) {
+	if (cylinders <= 1024 && (pbc != lbc || pbh != lbh || pbs != lbs)) {
 		printf("Partition %d has different physical/logical "
 			"beginnings (non-Linux?):\n", partition + 1);
 		printf("     phys=(%d, %d, %d) ", pbc, pbh, pbs);
@@ -737,7 +737,7 @@ static void check_consistency(struct partition *p, int partition)
 	}
 
 /* Same physical / logical ending? */
-	if (pec != lec || peh != leh || pes != les) {
+	if (cylinders <= 1024 && (pec != lec || peh != leh || pes != les)) {
 		printf("Partition %d has different physical/logical "
 			"endings:\n", partition + 1);
 		printf("     phys=(%d, %d, %d) ", pec, peh, pes);
