@@ -15,6 +15,8 @@
  *
  * History:
  *
+ * Version 1.4a: Sun Feb 26 18:08:45 1995, faith@cs.unc.edu
+ *               Forced devinfo and makedev to be in /etc
  * Version 1.4: 15-Jan-95  Wrote man pages. Now reads DEVINFO.local.
  * Version 1.3: 31-Dec-94  Bug fixes. Added batches. Added omits.
  * Version 1.2: 11-Dec-94  Add configuration file parsing.
@@ -25,7 +27,7 @@
  * Version 1.0: 10-Dec-94  Initial version.
  */
 
-static const char *version = "MAKEDEV-C version 1.4";
+static const char *version = "MAKEDEV-C version 1.4a";
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -124,11 +126,9 @@ static void addclass(const char *name, const char *o, const char *g, int m) {
 }
 
 static void loadclasses(void) {
-  FILE *f = fopen("MAKEDEV.cfg", "r");
-  if (!f) f = fopen("../MAKEDEV.cfg", "r");
-  if (!f) f = fopen("/etc/makedev.cfg", "r");
-  if (!f) crash("can't find MAKEDEV.cfg");
-  doparse(f, 4, "MAKEDEV.cfg");
+  FILE *f = fopen("/etc/makedev.cfg", "r");
+  if (!f) crash("can't find makedev.cfg");
+  doparse(f, 4, "makedev.cfg");
   fclose(f);
 }
 
@@ -514,18 +514,14 @@ static void initdisk(const char *base, int low, int high, int nparts,
 }
 
 static void initdevs(void) {
-  FILE *f = fopen("DEVINFO", "r");
-  if (!f) f = fopen("../DEVINFO", "r");
-  if (!f) f = fopen("/etc/devinfo", "r");
-  if (!f) crash("Can't find DEVINFO");
-  doparse(f,3, "DEVINFO");
+  FILE *f = fopen("/etc/devinfo", "r");
+  if (!f) crash("Can't find devinfo");
+  doparse(f,3, "devinfo");
   fclose(f);
-  f = fopen("DEVINFO.local", "r");
-  if (!f) f = fopen("../DEVINFO.local", "r");
-  if (!f) f = fopen("/etc/devinfo.local", "r");
+  f = fopen("/etc/devinfo.local", "r");
   if (!f) f = fopen("/usr/local/etc/devinfo.local", "r");
   if (f) {
-    doparse(f,3, "DEVINFO.local");
+    doparse(f,3, "devinfo.local");
     fclose(f);
   }
 }
@@ -655,8 +651,8 @@ static void make(const char *what, makeopts m) {
  * A major improvement over the shell version...
  */
 static void usage(void) {
-  printf("MAKEDEV usage:\n");
-  printf("    MAKEDEV [-vdcn] device [device...]\n");
+  printf("MAKEDEV-C usage:\n");
+  printf("    MAKEDEV-C [-vdcn] device [device...]\n");
   printf("      -v                 Verbose output\n");
   printf("      -d                 Remove specified devices\n");
   printf("      -c                 Create devices (default)\n");
@@ -678,8 +674,8 @@ int main(int argc, char **argv) {
 	case 'c': deletion = 0; break;
 	case 'n': donothing = 1; isverbose = 1; break;
 	case 'h': usage(); exit(0);
-	case 'V': printf("MAKEDEV: %s\n", version); exit(0);
-	default: fprintf(stderr, "MAKEDEV: unknown flag %c\n", argv[i][j]);
+	case 'V': printf("MAKEDEV-C: %s\n", version); exit(0);
+	default: fprintf(stderr, "MAKEDEV-C: unknown flag %c\n", argv[i][j]);
 	  exit(1);
     }
   setup_majors();      /* read major device numbers from /proc */
@@ -699,6 +695,8 @@ int main(int argc, char **argv) {
  AnaGram Parsing Engine
  Copyright (c) 1993, Parsifal Software.
  All Rights Reserved.
+ This module may be copied and/or distributed at the discretion of the
+ AnaGram licensee.
 
 */
 
