@@ -244,27 +244,35 @@ fstype(const char *device)
     fd = open(device, O_RDONLY);
     if (fd < 0) {
 	perror(device);
-	exit(1);
+	return 0;
     }
     lseek(fd, BLOCK_SIZE, SEEK_SET);
     read(fd, (char *) &ms, sizeof(ms));
-    if (ms.s_magic == MINIX_SUPER_MAGIC || ms.s_magic == MINIX_SUPER_MAGIC2)
+    if (ms.s_magic == MINIX_SUPER_MAGIC || ms.s_magic == MINIX_SUPER_MAGIC2) {
+        close(fd);
 	return("minix");
+    }
 
     lseek(fd, BLOCK_SIZE, SEEK_SET);
     read(fd, (char *) &es, sizeof(es));
-    if (es.s_magic == EXT_SUPER_MAGIC)
+    if (es.s_magic == EXT_SUPER_MAGIC) {
+        close(fd);
 	return("ext");
+    }
 
     lseek(fd, BLOCK_SIZE, SEEK_SET);
     read(fd, (char *) &e2s, sizeof(e2s));
-    if (e2s.s_magic == EXT2_SUPER_MAGIC || e2s.s_magic == EXT2_PRE_02B_MAGIC)
+    if (e2s.s_magic == EXT2_SUPER_MAGIC || e2s.s_magic == EXT2_PRE_02B_MAGIC) {
+        close(fd);
 	return("ext2");
+    }
 
     lseek(fd, 0, SEEK_SET);
     read(fd, (char *) &xfs, sizeof(xfs));
-    if (xfs.s_magic == _XIAFS_SUPER_MAGIC)
+    if (xfs.s_magic == _XIAFS_SUPER_MAGIC) {
+        close(fd);
 	return("xiafs");
+    }
 
     close(fd);
 
@@ -275,7 +283,6 @@ fstype(const char *device)
 
 /* Mount a single file system.  Return status,
    so don't exit on non-fatal errors.  */
-
  
 static int
 try_mount5 (char *spec, char *node, char **type, int flags, char *mount_opts) {
@@ -356,8 +363,8 @@ mount_one (char *spec, char *node, char *type, char *opts, int freq, int pass)
     die (1, "mount: this version doesn't support the type `nfs'");
 #endif
 
-  if (!type)
-  	type = fstype(spec);
+  if (!type && !(type = fstype(spec)))
+  	return 1;
 
   block_signals (SIG_BLOCK);
 
